package net.wanji.opt.common;

import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import net.wanji.opt.dto.CrossEventDTO;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.ZSetOperations;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Set;

/**
 * @description: redis工具类
 * @author wanji
 * @version 1.0
 * Created on 2019/4/29 20:34
 */
@Component
@Slf4j
public class RedisUtils {

    @Resource
    private RedisTemplate<String, Object> redis7Template;

    /**
     * 7号库获取最大 score zset 元素
     */
    public Object getMaxScoreElement(String redisKey) throws Exception {
        try {
            ObjectMapper objectMapper = new ObjectMapper();
            ZSetOperations<String, Object> zSetOps = redis7Template.opsForZSet();
            Set<Object> result = zSetOps.reverseRange(redisKey, 0, -1);

            if (result != null && !result.isEmpty()) {
                for (Object o : result) {
                    CrossEventDTO dto = objectMapper.readValue(o.toString(), CrossEventDTO.class);
                    String msgType = dto.getMsgType();
                    if (msgType.startsWith("50")) {
                        return o;
                    }
                }
            }
            log.error("redis获取数据key:{}, 获取value：{}", redisKey, result);
        } catch (Exception e) {
            //throw new RuntimeException(e);
        }
        return null;
    }


    /**
     * @description: 判断是否存在Key
     * @param key redis的Key
     * @return boolean true:有 false:无
     */
    public boolean hasKey(String key) {
        return redis7Template.hasKey(key);
    }

    /**
     * @description: 添加字符串
     * @param key redis的Key
     * @param value 添加redis的value
     */
    public void set(String key, String value) {
        redis7Template.opsForValue().set(key, value);
    }

    /**
     * @description: 获取对象
     * @param key redis的Key
     * @return Object 返回对象
     */
    public Object get(String key) {
        return redis7Template.opsForValue().get(key);
    }
}
