package net.wanji.opt.synthesis.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.utils.tool.JacksonUtils;
import net.wanji.opt.common.Constants;
import net.wanji.opt.common.RedisUtils;
import net.wanji.opt.service.GreenBeltInfoService;
import net.wanji.opt.vo.GreenBeltChartVO;
import net.wanji.opt.vo.GreenBeltInfoVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;

/**
 * @author duanruiming
 * @date 2024/11/19 20:10
 * @description 神思推送绿波时序图
 */
@Api(value = "StrategyGreenBeltController", description = "策略绿波带")
@RequestMapping("/strategyBelt")
@RestController
public class StrategyGreenBeltController {

    @Resource
    private RedisUtils redisUtils;
    @Resource
    private GreenBeltInfoService greenBeltInfoService;

    @ApiOperation(value = "绿波时序图数据查询", notes = "绿波时序图数据查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenBletData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenBeltInfoVO.class),
    })
    public JsonViewObject greenBletData(@RequestBody String greenId) throws Exception {

        // todo 测试
        GreenBeltInfoVO greenBeltInfoVO1 = greenBeltInfoService.convertData(null);
        greenBeltInfoService.save(greenBeltInfoVO1);
        String key = Constants.GREEN_ID_OPT_KEY.concat(greenId);
        redisUtils.set(key, JacksonUtils.getInstance().writeValueAsString(greenBeltInfoVO1));

        Object obj = redisUtils.get(key);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        GreenBeltInfoVO greenBeltInfoVO = JacksonUtils.getInstance().readValue(String.valueOf(obj), GreenBeltInfoVO.class);
        return jsonViewObject.success(greenBeltInfoVO);
    }

    @ApiOperation(value = "绿波时序图图形查询", notes = "绿波时序图图形查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenBeltChart",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenBeltInfoVO.class),
    })
    public JsonViewObject greenBeltChart(@RequestBody String greenId) throws Exception {
        String key = Constants.GREEN_ID_OPT_CHART_KEY.concat(greenId);
        Object obj = redisUtils.get(key);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        GreenBeltChartVO greenBeltChartVO = JacksonUtils.getInstance().readValue(String.valueOf(obj), GreenBeltChartVO.class);
        return jsonViewObject.success(greenBeltChartVO);
    }
}
